@@ -58,7 +58,7 @@ class SyncKohaRowsCommand(BaseCommand):
 
                 if not records:
                     SyncKohaRowsCommand.bypass()
-                    return
+                    return last_record
 
                 self.persist(records)
 
@@ -88,7 +88,7 @@ class SyncKohaRowsCommand(BaseCommand):
 
         if not records:
             SyncKohaRowsCommand.bypass()
-            return
+            return last_record
 
         self.persist(records, use_cache=True)
 
